@@ -7,7 +7,7 @@ var assert = require('assert/');
 var stream = require('../../');
 
 var r = new stream.Readable({
-  read: common.noop
+  read: function () {}
 });
 
 // readableListening state should start in `false`.
@@ -21,7 +21,7 @@ r.on('readable', common.mustCall(function () {
 r.push(bufferShim.from('Testing readableListening state'));
 
 var r2 = new stream.Readable({
-  read: common.noop
+  read: function () {}
 });
 
 // readableListening state should start in `false`.
